@@ -3,15 +3,23 @@ Helper functions for app.py
 """
 
 import os
+import re
 import shutil
 
 import h5py
 import numpy as np
 import pandas as pd
-import pylems_py2xml
+# import pylems_py2xml
 
 from sim2bids.app import app
 from sim2bids.generate import subjects as subj, zip_traversal as z
+from sim2bids.convert import mat
+from sim2bids.preprocess import preprocess
+from sim2bids.generate import utils as gen_utils
+
+
+ACCEPTED_RHYTHMS = ['alpha', 'delta', 'theta', 'gamma', 'beta']
+RHYTHMS = dict()
 
 
 def recursive_walk(path: str, basename: bool = False) -> list:
@@ -29,7 +37,6 @@ def recursive_walk(path: str, basename: bool = False) -> list:
     Returns
     -------
     """
-
     # create empty list to store paths
     content = []
 
@@ -40,28 +47,39 @@ def recursive_walk(path: str, basename: bool = False) -> list:
             if '.ipynb_checkpoints' in file:
                 continue
 
+            # find rhythms
+            find_rhythm(os.path.join(root, file))
+
             # extract files from zip folder
             if file.endswith('.zip'):
                 # add zip content to the files
                 content += z.extract_zip(os.path.join(root, file))
+
+                # remove zip folder to not get into recursion
+                os.remove(os.path.join(root, file))
                 continue
 
             if file.endswith('.h5'):
                 content += extract_h5(os.path.join(root, file))
 
+            if file.endswith('.mat'):
+                content += extract_mat(os.path.join(root, file), path)
+
+            if 'times' in file:
+                app.TIMES.append(subj.accepted(file)[-1])
+                app.TIMES = list(set(app.TIMES))
+
             # if code is found, save its location
             if file.endswith('.py'):
                 app.CODE = os.path.join(root, file)
-                temp = pylems_py2xml.main.XML(app.CODE, save=False)
+                # temp = pylems_py2xml.main.XML(app.CODE, save=False)
 
-                if temp.model_name == 'hindmarshrose':
-                    app.MODEL_NAME = 'SJHM3D'
-                elif temp.model_name == 'oscillator':
-                    app.MODEL_NAME = 'G2DOS'
+                # if temp.model_name == 'hindmarshrose':
+                #     app.MODEL_NAME = 'SJHM3D'
+                # elif temp.model_name == 'oscillator':
+                #     app.MODEL_NAME = 'G2DOS'
 
             # rename tract_lengths to distances
-            if 'tract_length' in files:
-                file = rename_tract_lengths(file)
 
             # save file name
             if basename:
@@ -97,14 +115,15 @@ def get_content(path: str, files: [str, list], basename: bool = False) -> list:
     -------
 
     """
-
     # if provided path contains only one sub-folder, and it's needed to traverse that,
     # return the whole content of the specified location.
     if isinstance(files, str):
         return recursive_walk(os.path.join(path, files))
 
     for file in files:
-        if os.path.isdir(os.path.join(path, file)) and file.startswith('.'):
+        if os.path.isdir(os.path.join(path, file)) and (file.startswith('.ipy') or file.startswith('.git') or
+                                                        file.startswith('.MS') or file.startswith('.idea') or
+                                                        file.startswith('vscode')):
             shutil.rmtree(os.path.join(path, file))
 
     # preprocess folder and remove all folders/files starting with '.'
@@ -122,13 +141,19 @@ def get_content(path: str, files: [str, list], basename: bool = False) -> list:
         # combine path
         file_path = os.path.join(path, file)
 
-        # check whether the selection is a directory
-        if os.path.isdir(file_path):
-            # disregard folders that start with '.'
-            if file_path.startswith('.'):
-                shutil.rmtree(file_path)
-                continue
+        if file.endswith('.m') or file.endswith('.R'):
+            if app.CODE is None:
+                app.CODE = []
+            app.CODE.append(file_path)
+            continue
 
+        find_rhythm(file_path)
+
+        if 'CHANGES' in file or 'participants' in file or 'README' in file:
+            app.MISSING.append(file_path)
+
+        # # check whether the selection is a directory
+        if os.path.isdir(file_path):
             # if true, traverse its content and append results
             contents += recursive_walk(file_path, basename)
 
@@ -140,10 +165,20 @@ def get_content(path: str, files: [str, list], basename: bool = False) -> list:
             extract_h5(file_path)
             continue
 
+        if file.endswith('.mat'):
+            contents += extract_mat(os.path.join(path, file), path)
+            continue
+
         # check if it's among the accepted extensions
         if ext in app.ACCEPTED_EXT:
-            # rename `tract_lengths` to `distances`
-            contents.append(rename_tract_lengths(file_path))
+            file = file_path
+
+            if basename:
+                # rename `tract_lengths` to `distances`
+                contents.append(os.path.basename(file))
+            else:
+                contents.append(file)
+
         # if code is found, save its location
         elif ext == 'py':
             app.CODE = os.path.join(path, file)
@@ -152,8 +187,18 @@ def get_content(path: str, files: [str, list], basename: bool = False) -> list:
     return contents
 
 
-def rename_tract_lengths(file: str) -> str:
-    return file.replace('tract_lengths', 'distances')
+def find_rhythm(path):
+    for rhythm in ACCEPTED_RHYTHMS:
+        if rhythm in path:
+            minutes = re.findall(r'[0-9]+min', path)
+            if minutes:
+                RHYTHMS[rhythm + '_' + minutes[0]] = []
+                return
+            RHYTHMS[rhythm] = []
+
+
+# def rename_tract_lengths(file: str) -> str:
+#     return file.replace('tract_lengths', 'distances')
 
 
 def get_files():
@@ -204,9 +249,28 @@ def extract_h5(path) -> list:
     return contents
 
 
+def extract_mat(path, og_path) -> list:
+    return mat.save_mat({'path': path, 'sid': preprocess.create_uuid(numbers=True)}, og_path, extract=True)
+
+
 def get_model():
     files = os.listdir(os.path.join(app.OUTPUT, 'param'))
 
     for file in files:
         if file.startswith('model-'):
             return file.split('_')[0].split('-')[-1]
+
+
+def infer_model():
+    if isinstance(app.CODE, str):
+        content = gen_utils.open_file(app.CODE)
+        model = re.findall(r'(?:hindmarsh|wongwang|oscillator)', ''.join(content), flags=re.IGNORECASE)
+
+        if model:
+            model = model[0].lower()
+            if 'hindmarsh' in model:
+                app.MODEL_NAME = 'HindmarshRose'
+            elif 'wongwang' in model:
+                app.MODEL_NAME = 'ReducedWongWang'
+            elif 'oscillator' in model:
+                app.MODEL_NAME = 'Generic2dOscillator'
