@@ -2,16 +2,18 @@ IDS = []
 start = 1
 
 
-def create_uuid():
+def create_uuid(numbers=False):
     global start
 
     if start in IDS:
         start += 1
 
-    new = f'sub-0{start}' if start < 10 else f'sub-{start}'
-
     IDS.append(start)
-    return new
+
+    if not numbers:
+        new = f'sub-0{start}' if start < 10 else f'sub-{start}'
+        return new
+    return str(start)
 
 
 def reset_index():
